#include <Arduino.h>


#ifdef ESP32
  #include <WiFi.h>
  int BAUD_RATE = 115200;
  
#elif defined(ARDUINO_UNOR4_WIFI)
    #include <WiFiS3.h>
    int BAUD_RATE = 9600;

#elif ESP8266
  #include <ESP8266WiFi.h>
  int BAUD_RATE = 9600;

#endif


////// ***** ChipChop definitions  ***** ///////
#include <ChipChopManager.h> 
ChipChopManager ChipChop;

//The connection credentials can be found in the device settings Dev Console > Devices
String server_uri = "...your allocated Endpoint Server URI..."; 
String uuid = "...your ChipChop UUID ..."; 
String auth_code = "... your Security Authentication Code ..."; 
String device_id = "... your Device ID ..."; // same Unique ID as you have specified in the Dev Console for this device, make sure that this is unique between all your devices

////// ***** Led variables ***** //////
unsigned long loopCycle = 0; // used in the main loop to avoid using the blocking delay()
String led_status = "OFF"; // the device will start with the led turned off
const int led_pin = 2; // define the pin that will control the led (pin 2 is the ESP8266 built in led)

// ChipChop callback function triggered every time you send a command to your device
// this callback will handle the switching of the led on/off
void ChipChop_onCommandReceived(String target_component,String command_value, String command_source, int command_age){

    if(target_component == "led"){
        if(command_value == "ON"){

            led_status = "ON"; //update the status
            digitalWrite(led_pin,LOW); // turn the led on

        }else if(command_value == "OFF"){

           led_status = "OFF";//update the status
            digitalWrite(led_pin,HIGH); // turn the led off
        }

    }

    ChipChop.updateStatus("led",led_status); // Confirm the LED status change

}


void setup()
{

    Serial.begin(BAUD_RATE);

    WiFi.begin("< your SSID >", "< your wifi password >");

    Serial.print("WiFi Connecting");
    while (WiFi.status() != WL_CONNECTED)
    {
        delay(500);
        Serial.print(".");
    }

    pinMode(led_pin,OUTPUT); // declare the led pin as an output
    digitalWrite(led_pin,HIGH); // turn the led off

    //*** declare ChipChop utility callbacks, functions & settings ***//
    ChipChop.commandCallback(ChipChop_onCommandReceived);
    ChipChop.start(server_uri, uuid, device_id, auth_code);
    ChipChop.debug(true); // enables log messages from the ChipChop library, set to false in production
   
    ChipChop.updateStatus("led",led_status); // You should always set the initial status of all components 

}


void loop(){

  ChipChop.run(); // This call has to be here in the main loop() and needs to run continuously

}

